[Bug rtl-optimization/8126] [3.3/3.4/4.0 regression] Floating point computation far slower in 3.2 than in 2.95

ian at airs dot com gcc-bugzilla@gcc.gnu.org
Sun Jan 16 03:35:00 GMT 2005


------- Additional Comments From ian at airs dot com  2005-01-16 03:35 -------
If we're going to mark this as a regression, can somebody pin down the cases
where mainline gcc is slower than gcc 2.95?

On my system it is about 35% faster.  But that is on a Pentium 4.

I know that Roger Sayle did some work on reg-stack shuffling, but I don't know
how much that affects this PR, if at all.


-- 
           What    |Removed                     |Added
----------------------------------------------------------------------------
                 CC|                            |ian at airs dot com


http://gcc.gnu.org/bugzilla/show_bug.cgi?id=8126



More information about the Gcc-bugs mailing list